@@ -1,9 +1,9 @@
 package App::ThisDist;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-02'; # DATE
+our $DATE = '2020-10-03'; # DATE
 our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Print Perl {distribution,module,author,...} associated with current directory
@@ -20,7 +20,19 @@ App::ThisDist - Print Perl {distribution,module,author,...} associated with curr
 
 =head1 VERSION
 
-This document describes version 0.003 of App::ThisDist (from Perl distribution App-ThisDist), released on 2020-10-02.
+This document describes version 0.004 of App::ThisDist (from Perl distribution App-ThisDist), released on 2020-10-03.
+
+=head1 DESCRIPTION
+
+See included scripts:
+
+=over
+
+=item * L<this-dist>
+
+=back
+
+
 
 =head1 HOMEPAGE
 
@@ -40,15 +52,7 @@ feature.
 
 =head1 SEE ALSO
 
-See included scripts:
-
-=over
-
-=item * L<this-dist>
-
-=back
-
-
+L<App::DistUtils>
 
 =head1 AUTHOR
 
